@@ -1,7 +1,6 @@
-#!/usr/bin/python
-"""
-Tests for gtimelog/main.py
-"""
+#!/usr/bin/env python
+
+"""Tests for gtimelog/main.py"""
 
 import doctest
 import unittest
@@ -231,137 +230,6 @@ def doctest_uniq():
 
     """
 
-def doctest_TimeWindow_report_categories():
-    r"""Tests for TimeWindow.report_categories
-
-        >>> import sys
-
-        >>> from datetime import datetime, time, timedelta
-        >>> from tempfile import NamedTemporaryFile
-        >>> from gtimelog.main import TimeWindow
-
-        >>> vm = time(2, 0)
-        >>> min = datetime(2010, 1, 25)
-        >>> max = datetime(2010, 1, 31)
-        >>> fh = NamedTemporaryFile()
-
-        >>> categories = {
-        ...    'Bing': timedelta(2),
-        ...    None: timedelta(1)}
-
-        >>> window = TimeWindow(fh.name, min, max, vm)
-        >>> window.report_categories(sys.stdout, categories)
-        <BLANKLINE>
-        By category:
-        <BLANKLINE>
-        Bing                                                            48 hours
-        (none)                                                          24 hours
-        <BLANKLINE>
-
-    """
-
-def doctest_TimeWindow_weekly_report():
-    r"""Tests for TimeWindow.weekly_report
-
-        >>> import sys
-
-        >>> from datetime import datetime, time
-        >>> from tempfile import NamedTemporaryFile
-        >>> from gtimelog.main import TimeWindow
-
-        >>> vm = time(2, 0)
-        >>> min = datetime(2010, 1, 25)
-        >>> max = datetime(2010, 1, 31)
-        >>> fh = NamedTemporaryFile()
-
-        >>> window = TimeWindow(fh.name, min, max, vm)
-        >>> window.weekly_report(sys.stdout, 'foo@bar.com', 'Bob Jones')
-        To: foo@bar.com
-        Subject: Weekly report for Bob Jones (week 04)
-        <BLANKLINE>
-        No work done this week.
-
-        >>> _ = [fh.write(s + '\n') for s in [
-        ...    '2010-01-30 09:00: start',
-        ...    '2010-01-30 09:23: Bing: stuff',
-        ...    '2010-01-30 12:54: Bong: other stuff',
-        ...    '2010-01-30 13:32: lunch **',
-        ...    '2010-01-30 15:46: misc',
-        ...    '']]
-        >>> fh.flush()
-
-        >>> window = TimeWindow(fh.name, min, max, vm)
-        >>> window.weekly_report(sys.stdout, 'foo@bar.com', 'Bob Jones')
-        To: foo@bar.com
-        Subject: Weekly report for Bob Jones (week 04)
-        <BLANKLINE>
-                                                                        time
-        Bing: stuff                                                     23 min
-        Bong: other stuff                                               3 hours 31 min
-        Misc                                                            2 hours 14 min
-        <BLANKLINE>
-        Total work done this week: 6 hours 8 min
-        <BLANKLINE>
-        By category:
-        <BLANKLINE>
-        Bing                                                            23 min
-        Bong                                                            3 hours 31 min
-        (none)                                                          2 hours 14 min
-        <BLANKLINE>
-
-    """
-
-def doctest_TimeWindow_monthly_report():
-    r"""Tests for TimeWindow.monthly_report
-
-        >>> import sys
-
-        >>> from datetime import datetime, time
-        >>> from tempfile import NamedTemporaryFile
-        >>> from gtimelog.main import TimeWindow
-
-        >>> vm = time(2, 0)
-        >>> min = datetime(2007, 9, 1)
-        >>> max = datetime(2007, 10, 1)
-        >>> fh = NamedTemporaryFile()
-
-        >>> window = TimeWindow(fh.name, min, max, vm)
-        >>> window.monthly_report(sys.stdout, 'foo@bar.com', 'Bob Jones')
-        To: foo@bar.com
-        Subject: Monthly report for Bob Jones (2007/09)
-        <BLANKLINE>
-        No work done this month.
-
-        >>> _ = [fh.write(s + '\n') for s in [
-        ...    '2007-09-30 09:00: start',
-        ...    '2007-09-30 09:23: Bing: stuff',
-        ...    '2007-09-30 12:54: Bong: other stuff',
-        ...    '2007-09-30 13:32: lunch **',
-        ...    '2007-09-30 15:46: misc',
-        ...    '']]
-        >>> fh.flush()
-
-        >>> window = TimeWindow(fh.name, min, max, vm)
-        >>> window.monthly_report(sys.stdout, 'foo@bar.com', 'Bob Jones')
-        To: foo@bar.com
-        Subject: Monthly report for Bob Jones (2007/09)
-        <BLANKLINE>
-        <BLANKLINE>
-        Bing: stuff                                                     23 min
-        Bong: other stuff                                               3 hours 31 min
-        Misc                                                            2 hours 14 min
-        <BLANKLINE>
-        Total work done this month: 6 hours 8 min
-        <BLANKLINE>
-        By category:
-        <BLANKLINE>
-        Bing                                                            23 min
-        Bong                                                            3 hours 31 min
-        (none)                                                          2 hours 14 min
-        <BLANKLINE>
-
-    """
-
 def doctest_TimeWindow_to_csv_daily():
     r"""Tests for TimeWindow.to_csv_daily
 
@@ -392,6 +260,331 @@ def doctest_TimeWindow_to_csv_daily():
 
     """
 
+def doctest_Reports_weekly_report_categorized():
+    r"""Tests for Reports.weekly_report_categorized
+
+        >>> import sys
+
+        >>> from datetime import datetime, time
+        >>> from tempfile import NamedTemporaryFile
+        >>> from gtimelog.main import TimeWindow, Reports
+
+        >>> vm = time(2, 0)
+        >>> min = datetime(2010, 1, 25)
+        >>> max = datetime(2010, 1, 31)
+        >>> fh = NamedTemporaryFile()
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports.weekly_report_categorized(sys.stdout, 'foo@bar.com',
+        ...                                   'Bob Jones')
+        To: foo@bar.com
+        Subject: Weekly report for Bob Jones (week 04)
+        <BLANKLINE>
+        No work done this week.
+
+        >>> _ = [fh.write(s + '\n') for s in [
+        ...    '2010-01-30 09:00: start',
+        ...    '2010-01-30 09:23: Bing: stuff',
+        ...    '2010-01-30 12:54: Bong: other stuff',
+        ...    '2010-01-30 13:32: lunch **',
+        ...    '2010-01-30 23:46: misc',
+        ...    '']]
+        >>> fh.flush()
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports.weekly_report_categorized(sys.stdout, 'foo@bar.com',
+        ...                                   'Bob Jones')
+        To: foo@bar.com
+        Subject: Weekly report for Bob Jones (week 04)
+        <BLANKLINE>
+                                                                        time
+        Bing:
+        <BLANKLINE>
+          Stuff                                                           0:23
+        ----------------------------------------------------------------------
+                                                                          0:23
+        <BLANKLINE>
+        Bong:
+        <BLANKLINE>
+          Other stuff                                                     3:31
+        ----------------------------------------------------------------------
+                                                                          3:31
+        <BLANKLINE>
+        No category:
+        <BLANKLINE>
+          Misc                                                           10:14
+        ----------------------------------------------------------------------
+                                                                         10:14
+        <BLANKLINE>
+        Total work done this week: 14:08
+        <BLANKLINE>
+        Categories by time spent:
+          No category     10:14
+          Bong             3:31
+          Bing             0:23
+
+    """
+
+def doctest_Reports_monthly_report_categorized():
+    r"""Tests for Reports.monthly_report_categorized
+
+        >>> import sys
+
+        >>> from datetime import datetime, time
+        >>> from tempfile import NamedTemporaryFile
+        >>> from gtimelog.main import TimeWindow, Reports
+
+        >>> vm = time(2, 0)
+        >>> min = datetime(2010, 1, 25)
+        >>> max = datetime(2010, 1, 31)
+        >>> fh = NamedTemporaryFile()
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports.monthly_report_categorized(sys.stdout, 'foo@bar.com',
+        ...                                   'Bob Jones')
+        To: foo@bar.com
+        Subject: Monthly report for Bob Jones (2010/01)
+        <BLANKLINE>
+        No work done this month.
+
+        >>> _ = [fh.write(s + '\n') for s in [
+        ...    '2010-01-30 09:00: start',
+        ...    '2010-01-30 09:23: Bing: stuff',
+        ...    '2010-01-30 12:54: Bong: other stuff',
+        ...    '2010-01-30 13:32: lunch **',
+        ...    '2010-01-30 23:46: misc',
+        ...    '']]
+        >>> fh.flush()
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports.monthly_report_categorized(sys.stdout, 'foo@bar.com',
+        ...                                   'Bob Jones')
+        To: foo@bar.com
+        Subject: Monthly report for Bob Jones (2010/01)
+        <BLANKLINE>
+                                                                          time
+        Bing:
+          Stuff                                                           0:23
+        ----------------------------------------------------------------------
+                                                                          0:23
+        <BLANKLINE>
+        Bong:
+          Other stuff                                                     3:31
+        ----------------------------------------------------------------------
+                                                                          3:31
+        <BLANKLINE>
+        No category:
+          Misc                                                           10:14
+        ----------------------------------------------------------------------
+                                                                         10:14
+        <BLANKLINE>
+        Total work done this month: 14:08
+        <BLANKLINE>
+        Categories by time spent:
+          No category     10:14
+          Bong             3:31
+          Bing             0:23
+
+    """
+
+def doctest_Reports_report_categories():
+    r"""Tests for Reports._report_categories
+
+        >>> import sys
+
+        >>> from datetime import datetime, time, timedelta
+        >>> from tempfile import NamedTemporaryFile
+        >>> from gtimelog.main import TimeWindow, Reports
+
+        >>> vm = time(2, 0)
+        >>> min = datetime(2010, 1, 25)
+        >>> max = datetime(2010, 1, 31)
+        >>> fh = NamedTemporaryFile()
+
+        >>> categories = {
+        ...    'Bing': timedelta(2),
+        ...    None: timedelta(1)}
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports._report_categories(sys.stdout, categories)
+        <BLANKLINE>
+        By category:
+        <BLANKLINE>
+        Bing                                                            48 hours
+        (none)                                                          24 hours
+        <BLANKLINE>
+
+    """
+
+def doctest_Reports_daily_report():
+    r"""Tests for Reports.daily_report
+        >>> import sys
+
+        >>> from datetime import datetime, time
+        >>> from tempfile import NamedTemporaryFile
+        >>> from gtimelog.main import TimeWindow, Reports
+
+        >>> vm = time(2, 0)
+        >>> min = datetime(2010, 1, 30)
+        >>> max = datetime(2010, 1, 31)
+        >>> fh = NamedTemporaryFile()
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports.daily_report(sys.stdout, 'foo@bar.com', 'Bob Jones')
+        To: foo@bar.com
+        Subject: 2010-01-30 report for Bob Jones (Sat, week 04)
+        <BLANKLINE>
+        No work done today.
+
+        >>> _ = [fh.write(s + '\n') for s in [
+        ...    '2010-01-30 09:00: start',
+        ...    '2010-01-30 09:23: Bing: stuff',
+        ...    '2010-01-30 12:54: Bong: other stuff',
+        ...    '2010-01-30 13:32: lunch **',
+        ...    '2010-01-30 15:46: misc',
+        ...    '']]
+        >>> fh.flush()
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports.daily_report(sys.stdout, 'foo@bar.com', 'Bob Jones')
+        To: foo@bar.com
+        Subject: 2010-01-30 report for Bob Jones (Sat, week 04)
+        <BLANKLINE>
+        Start at 09:00
+        <BLANKLINE>
+        Bing: stuff                                                     23 min
+        Bong: other stuff                                               3 hours 31 min
+        Misc                                                            2 hours 14 min
+        <BLANKLINE>
+        Total work done: 6 hours 8 min
+        <BLANKLINE>
+        By category:
+        <BLANKLINE>
+        Bing                                                            23 min
+        Bong                                                            3 hours 31 min
+        (none)                                                          2 hours 14 min
+        <BLANKLINE>
+        Slacking:
+        <BLANKLINE>
+        Lunch **                                                        38 min
+        <BLANKLINE>
+        Time spent slacking: 38 min
+
+    """
+
+def doctest_Reports_weekly_report_plain():
+    r"""Tests for Reports.weekly_report_plain
+
+        >>> import sys
+
+        >>> from datetime import datetime, time
+        >>> from tempfile import NamedTemporaryFile
+        >>> from gtimelog.main import TimeWindow, Reports
+
+        >>> vm = time(2, 0)
+        >>> min = datetime(2010, 1, 25)
+        >>> max = datetime(2010, 1, 31)
+        >>> fh = NamedTemporaryFile()
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports.weekly_report_plain(sys.stdout, 'foo@bar.com', 'Bob Jones')
+        To: foo@bar.com
+        Subject: Weekly report for Bob Jones (week 04)
+        <BLANKLINE>
+        No work done this week.
+
+        >>> _ = [fh.write(s + '\n') for s in [
+        ...    '2010-01-30 09:00: start',
+        ...    '2010-01-30 09:23: Bing: stuff',
+        ...    '2010-01-30 12:54: Bong: other stuff',
+        ...    '2010-01-30 13:32: lunch **',
+        ...    '2010-01-30 15:46: misc',
+        ...    '']]
+        >>> fh.flush()
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports.weekly_report_plain(sys.stdout, 'foo@bar.com', 'Bob Jones')
+        To: foo@bar.com
+        Subject: Weekly report for Bob Jones (week 04)
+        <BLANKLINE>
+                                                                        time
+        Bing: stuff                                                     23 min
+        Bong: other stuff                                               3 hours 31 min
+        Misc                                                            2 hours 14 min
+        <BLANKLINE>
+        Total work done this week: 6 hours 8 min
+        <BLANKLINE>
+        By category:
+        <BLANKLINE>
+        Bing                                                            23 min
+        Bong                                                            3 hours 31 min
+        (none)                                                          2 hours 14 min
+        <BLANKLINE>
+
+    """
+
+def doctest_Reports_monthly_report_plain():
+    r"""Tests for Reports.monthly_report_plain
+
+        >>> import sys
+
+        >>> from datetime import datetime, time
+        >>> from tempfile import NamedTemporaryFile
+        >>> from gtimelog.main import TimeWindow, Reports
+
+        >>> vm = time(2, 0)
+        >>> min = datetime(2007, 9, 1)
+        >>> max = datetime(2007, 10, 1)
+        >>> fh = NamedTemporaryFile()
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports.monthly_report_plain(sys.stdout, 'foo@bar.com', 'Bob Jones')
+        To: foo@bar.com
+        Subject: Monthly report for Bob Jones (2007/09)
+        <BLANKLINE>
+        No work done this month.
+
+        >>> _ = [fh.write(s + '\n') for s in [
+        ...    '2007-09-30 09:00: start',
+        ...    '2007-09-30 09:23: Bing: stuff',
+        ...    '2007-09-30 12:54: Bong: other stuff',
+        ...    '2007-09-30 13:32: lunch **',
+        ...    '2007-09-30 15:46: misc',
+        ...    '']]
+        >>> fh.flush()
+
+        >>> window = TimeWindow(fh.name, min, max, vm)
+        >>> reports = Reports(window)
+        >>> reports.monthly_report_plain(sys.stdout, 'foo@bar.com', 'Bob Jones')
+        To: foo@bar.com
+        Subject: Monthly report for Bob Jones (2007/09)
+        <BLANKLINE>
+                                                                       time
+        Bing: stuff                                                     23 min
+        Bong: other stuff                                               3 hours 31 min
+        Misc                                                            2 hours 14 min
+        <BLANKLINE>
+        Total work done this month: 6 hours 8 min
+        <BLANKLINE>
+        By category:
+        <BLANKLINE>
+        Bing                                                            23 min
+        Bong                                                            3 hours 31 min
+        (none)                                                          2 hours 14 min
+        <BLANKLINE>
+
+    """
+
 
 def additional_tests(): # for setup.py
     return doctest.DocTestSuite(optionflags=doctest.NORMALIZE_WHITESPACE)
